@@ -26,7 +26,7 @@ from ifcopenshell.util.selector import Selector
 #IMPORT MODULES
 from geomapi.nodes import GeometryNode
 import geomapi.utils as ut
-import geomapi.utils.geometryutils as gt
+import geomapi.utils.geometryutils as gmu
 
 class BIMNode (GeometryNode):
     def __init__(self,  graph : Graph = None, 
@@ -129,7 +129,7 @@ class BIMNode (GeometryNode):
         elif 'Trimesh' in str(type(value)):
             self._resource=  value.as_open3d
         elif type(value) is ifcopenshell.entity_instance:
-            self._resource= gt.ifc_to_mesh(value)
+            self._resource= gmu.ifc_to_mesh(value)
             self.name=value.Name
             self.className=value.is_a()
             self.globalId=value.GlobalId
@@ -160,9 +160,9 @@ class BIMNode (GeometryNode):
             try:
                 ifc = ifcopenshell.open(self.ifcPath)   
                 ifcElement= ifc.by_guid(self.get_globalId())
-                self._resource=gt.ifc_to_mesh(ifcElement)
+                self._resource=gmu.ifc_to_mesh(ifcElement)
             except:
-                print('mesh=gt.ifc_to_mesh(ifcElement) error')
+                print('mesh=gmu.ifc_to_mesh(ifcElement) error')
         return self._resource  
 
     def get_globalId(self):
@@ -199,8 +199,8 @@ class BIMNode (GeometryNode):
             raise ValueError('Invalid extension')
 
         # check if already exists
-        if directory and os.path.exists(os.path.join(directory,self.get_name() + extension)):
-            self.path=os.path.join(directory,self.get_name() + extension)
+        if directory and os.path.exists(os.path.join(directory,self.subject + extension)):
+            self.path=os.path.join(directory,self.subject + extension)
             return True
         elif not directory and self.get_path() and os.path.exists(self.path) and extension in ut.MESH_EXTENSION:
             return True
@@ -219,7 +219,7 @@ class BIMNode (GeometryNode):
         if not os.path.exists(directory):                        
             os.mkdir(directory) 
 
-        self.path=os.path.join(directory,ut.get_filename(self.get_name()) + extension) #subject.toPython() replaced by get_name()
+        self.path=os.path.join(directory,ut.get_filename(self.subject) + extension) #subject.toPython() replaced by get_name()
 
         #write files
         if o3d.io.write_triangle_mesh(self.path, self.resource):
@@ -298,7 +298,7 @@ class BIMNode (GeometryNode):
                                                     [0,0,0,1]])
 
             if getattr(self,'cartesianBounds',None) is  None:
-                self.cartesianBounds=gt.get_cartesian_bounds(self.resource)
+                self.cartesianBounds=gmu.get_cartesian_bounds(self.resource)
             if getattr(self,'orientedBoundingBox',None) is  None:
                 self.orientedBoundingBox=self.resource.get_oriented_bounding_box()
             if getattr(self,'orientedBounds',None) is  None:
