@@ -412,7 +412,7 @@ class ImageNode(Node):
         else:
             return None
 
-    def get_virtual_image(self, geometries: o3d.geometry, downsampling:int=2)-> o3d.cpu.pybind.geometry.Image:
+    def get_virtual_image(self, geometries: o3d.geometry, downsampling:int=2)-> o3d.geometry.Image:
         """Generates a virtual image of a set of geometries given the ImageNode's pose and piholeModel.
 
         .. image:: ../../../docs/pics/rendering3.PNG
@@ -423,7 +423,7 @@ class ImageNode(Node):
             2. downsampling (int, optional): pixel downsampling of the image both in height and width (each step reduces the density by factor 4). Defaults to 2.
 
         Returns:
-            o3d.cpu.pybind.geometry.Image or None
+            o3d.geometry.Image or None
         """
         pinholeCamera=self.get_pinhole_camera_parameters(downsampling)
         if pinholeCamera is not None:
@@ -431,7 +431,7 @@ class ImageNode(Node):
         else:
             return None
 
-    def get_pinhole_camera_parameters(self, downsampling:int=2) -> o3d.camera.PinholeCameraParameters():
+    def get_pinhole_camera_parameters(self, downsampling:int=1) -> o3d.camera.PinholeCameraParameters():
         """Returns the intrinsic and extrinsix camera parameters based on the following attributes.
 
         .. image:: ../../../docs/pics/pinholemodel1.PNG
@@ -448,7 +448,8 @@ class ImageNode(Node):
         """
         param=o3d.camera.PinholeCameraParameters()
         if getattr(self,'cartesianTransform',None) is not None:
-            param.extrinsic=np.linalg.inv(self.cartesianTransform)
+            # param.extrinsic=np.linalg.inv(self.cartesianTransform) #! unsure why this was inverted
+            param.extrinsic=self.cartesianTransform            
             param.intrinsic=self.get_intrinsic_camera_parameters(downsampling)
             self.pinholeCamera=param
             return self.pinholeCamera
@@ -468,25 +469,16 @@ class ImageNode(Node):
         Returns:
             o3d.camera.PinholeCameraIntrinsic(width,height,fx,fy,cx,cy)
         """
-        width=640
-        height=480
-        f=25
+        #validate inputs
+        width=int(self.imageWidth/downsampling) if getattr(self,'imageWidth',None) is not None else 640
+        height=int(self.imageHeight/downsampling) if getattr(self,'imageHeight',None) is not None else 480
+        f=self.focalLength35mm if getattr(self,'focalLength35mm',None) is not None else 25
 
-        if getattr(self,'imageWidth',None) is not None:
-            width=int(self.imageWidth/downsampling)
-        if getattr(self,'imageHeight',None) is not None:
-            height=int(self.imageHeight/downsampling)
-        if getattr(self,'focalLength35mm',None) is not None:
-            f=self.focalLength35mm
-
-        pixX=width/36 #these are standard 35mm film properties
-        pixY=height/24 #these are standard 35mm film properties
-        fx=pixX*f
-        fy=pixY*f
-        
-        #! f should be in px in opencv, why are these smaller? (this was important for open3D)
-        fx=f
-        fy=f
+        #! deprecated
+        # pixX=width/36 #these are standard 35mm film properties
+        # pixY=height/24 #these are standard 35mm film properties
+        # fx=pixX*f
+        # fy=pixY*f        
 
         if (getattr(self,'principalPointU',None) is not None and
             getattr(self,'principalPointV',None) is not None ):
@@ -495,7 +487,7 @@ class ImageNode(Node):
         else:
             cx=width/2-0.5
             cy=height/2-0.5
-        pinholeCameraIntrinsic = o3d.camera.PinholeCameraIntrinsic(width,height,fx,fy,cx,cy)
+        pinholeCameraIntrinsic = o3d.camera.PinholeCameraIntrinsic(width,height,f,f,cx,cy)
         self.intrinsic_matrix = pinholeCameraIntrinsic.intrinsic_matrix
         return pinholeCameraIntrinsic
 
@@ -647,7 +639,7 @@ class ImageNode(Node):
         self.timestamp=ut.get_timestamp(self.xmlPath)        
         mytree = ET.parse(self.xmlPath)
         root = mytree.getroot()          
-        xmlNode = next(cam for cam in root.findall('.//camera') if (cam.get('label') ==self.name or cam.get('label') ==ut.get_subject_name(self.subject) ))
+        xmlNode = next(cam for cam in root.findall('.//camera') if (ut.get_filename(cam.get('label')) == self.name or ut.get_filename(cam.get('label')) == ut.get_subject_name(self.subject) ))
         
         if xmlNode:
             #AGISOFT PARSING 1
