@@ -11,7 +11,6 @@ Goals:\n
 - Attach spatial en temporal analyses through RDF Graph navigation   \n
     
 """
-
 #IMPORT PACKAGES
 from operator import contains
 import os
@@ -21,7 +20,6 @@ from typing import List
 import uuid
 import datetime
 import numpy as np
-from pathlib import Path
 
 from rdflib import Graph, URIRef, Literal
 import rdflib
@@ -430,16 +428,6 @@ class Node:
         """
         if getattr(self,'resource',None) is not None:
             self.resource=None
-
-        # #TEMP
-        # if getattr(self,'mesh',None) is not None:
-        #     self.mesh=None
-        # if getattr(self,'image',None) is not None:
-        #     self.image=None
-        # if getattr(self,'pcd',None) is not None:
-        #     self.pcd=None
-        # if getattr(self,'ortho',None) is not None:
-        #     self.ortho=None
             
     def get_path(self) -> str:
         """Returns the full path of the resource from this Node.\n
