@@ -426,7 +426,7 @@ class SessionNode(GeometryNode):
         if getattr(self,'timestamp',None) is None and self.linkedNodes:
             self.timestamp=self.linkedNodes[0].get_timestamp()
 
-        points=o3d.cpu.pybind.utility.Vector3dVector()        
+        points=o3d.utility.Vector3dVector()        
         for node in self.linkedNodes: 
             if getattr(node,'get_oriented_bounding_box',None) is not None:           
                 box=node.get_oriented_bounding_box()
@@ -436,7 +436,7 @@ class SessionNode(GeometryNode):
             elif getattr(node,'cartesianTransform',None) is not None:
                 t=gmu.get_translation(node.get_cartesian_transform())
                 t=np.reshape(t,(1,3))
-                p=o3d.cpu.pybind.utility.Vector3dVector(t)
+                p=o3d.utility.Vector3dVector(t)
                 points.extend(p)
 
         if np.asarray(points).shape[0] >=5:    
@@ -533,7 +533,7 @@ class SessionNode(GeometryNode):
         elif self.get_path():
             self._resource   =  o3d.io.read_triangle_mesh(self.path)
         elif self.linkedNodes:
-            points=o3d.cpu.pybind.utility.Vector3dVector()
+            points=o3d.utility.Vector3dVector()
             for node in self.linkedNodes: 
                 if getattr(node,'get_bounding_box',None):           
                     box=node.get_bounding_box()
