@@ -5,10 +5,131 @@ import numpy as np
 import open3d as o3d
 import geomapi.utils as ut
 import geomapi.utils.geometryutils as gmu
+import geomapi.utils.imageutils as iu
 from typing import List,Tuple
 from colour import Color
 from geomapi.nodes import ImageNode
 import copy 
+import os
+
+def create_voxel_block_grid_and_raytrace(pcd,imageNode):
+    """THIS CURRENTLY DOESNT WORK BUT IS A PLACEHOLDER.
+
+    Args:
+        pcd (_type_): _description_
+        imageNode (_type_): _description_
+    """
+    import open3d.core as o3c
+    intrinsic=imageNode.get_intrinsic_camera_parameters().intrinsic_matrix
+    extrinsic=imageNode.cartesianTransform
+    w=imageNode.imageWidth
+    h=imageNode.imageHeight
+    depth_scale=1
+    depth_min=0
+    depth_max=30
+    vbg = o3d.t.geometry.VoxelBlockGrid(
+                    attr_names=('tsdf', 'weight', 'color'),
+                    attr_dtypes=(o3c.float32, o3c.float32, o3c.float32),
+                    attr_channels=((1), (1), (3)),
+                    voxel_size=3.0 / 512,
+                    block_resolution=16,
+                    block_count=50000)
+    active_voxels=vbg.compute_unique_block_coordinates(pcd)
+    print(active_voxels)
+    result = vbg.ray_cast(block_coords=active_voxels,
+                              intrinsic=o3d.core.Tensor(intrinsic.intrinsic_matrix),
+                              extrinsic=extrinsic,
+                              width=640,
+                              height=480,
+                              render_attributes=[
+                                  'depth', 'normal', 'color', 'index',
+                                  'interp_ratio'
+                              ],
+                              depth_scale=depth_scale,
+                              depth_min=depth_min,
+                              depth_max=depth_max,
+                              weight_threshold=1,
+                              range_map_down_factor=8)
+    # fig, axs = plt.subplots(2, 2)
+
+    # # Colorized depth
+    # colorized_depth = o3d.t.geometry.Image(result['depth']).colorize_depth(depth_scale,depth_min,depth_max)
+    # # Render color via indexing
+    # vbg_color = vbg.attribute('color').reshape((-1, 3))
+    # nb_indices = result['index'].reshape((-1))
+    # nb_interp_ratio = result['interp_ratio'].reshape((-1, 1))
+    # nb_colors = vbg_color[nb_indices] * nb_interp_ratio
+    # sum_colors = nb_colors.reshape((480, 640, 8, 3)).sum(
+    #     (2)) / 255.0
+    # t=colorized_depth.as_tensor().cpu().numpy()
+    # print(t)
+    # axs[0, 0].imshow(colorized_depth.as_tensor().cpu().numpy())
+    # axs[0, 0].set_title('depth')
+
+    # axs[0, 1].imshow(result['normal'].cpu().numpy())
+    # axs[0, 1].set_title('normal')
+
+    # axs[1, 0].imshow(result['color'].cpu().numpy())
+    # axs[1, 0].set_title('color via kernel')
+
+    # axs[1, 1].imshow(sum_colors.cpu().numpy())
+    # axs[1, 1].set_title('color via indexing')
+
+    # plt.tight_layout()
+    # plt.show()
+
+def pcd_to_octree(pcd:o3d.geometry.PointCloud, maDepth:int=7,colorUse:int=0)->o3d.geometry.Octree:
+    """Create octree of point cloud and optionally color it consistently.
+
+    Args:
+        pcd (o3d.geometry.PointCloud): 
+        colorUse (int, optional): If 0, the colors per leafNode will be averaged. If 1, the dominant color per LeafNode will be retained (this is quite slow). Defaults to 0.
+
+    Returns:
+        o3d.geometry.Octree: 
+    """
+    octree=o3d.geometry.Octree(max_depth=maDepth)
+    octree.convert_from_point_cloud(pcd)
+    def f_traverse_set_majority_color(node, node_info):
+        """Callback function that changes the color to the dominant color in each leafnode.
+        """
+        if isinstance(node, o3d.geometry.OctreeLeafNode):
+            if isinstance(node, o3d.geometry.OctreePointColorLeafNode):               
+                myPcd=pcd.select_by_index(node.indices)
+                colors=np.asarray(myPcd.colors)
+                c=iu.rgb2gray(colors)
+                _, counts = np.unique(c, return_counts=True)
+                color=colors[np.argmax(counts)]
+                node.color=color
+        return None
+    octree.traverse(f_traverse_set_majority_color) if colorUse==1 else None
+    
+    return octree
+
+def capture_image_and_depth_viewer(pcdNode,imgNodes,imagePath,depthPath):
+    """Visualizer currently is bugged in Open3D and doesn't allow custom sizes. 
+    """
+    pcd=copy.deepcopy(pcdNode.resource)
+    # voxelGrid = o3d.geometry.VoxelGrid.create_from_point_cloud(pcd,voxel_size=0.4)
+    # n=imgNodes[0]
+    # intrinsic=n.get_intrinsic_camera_parameters().intrinsic_matrix
+    # extrinsic=n.cartesianTransform
+    # w=int(n.imageWidth/8)
+    # h=int(n.imageHeight/8)
+    # depth_scale=1
+    # depth_min=0
+    # depth_max=30
+    # camera_parameters=n.get_pinhole_camera_parameters(downsampling=8)
+    # voxelGrid=o3d.geometry.VoxelGrid.create_from_point_cloud(pcd,0.4)
+    # viewer = o3d.visualization.Visualizer() #! this currently is bugged in Open3D and doesn't allow custom sizes
+    # viewer.create_window()
+    # viewer.add_geometry(voxelGrid)
+    # # control = viewer.get_view_control() #! this currently is bugged in Open3D
+    # # print(control.convert_to_pinhole_camera_parameters().intrinsic)
+    # # control.convert_from_pinhole_camera_parameters(camera_parameters)
+    # viewer.capture_depth_image(os.path.join(imagePath, "{:04d}-depth.png".format(1)), do_render=True, depth_scale=1000.0)
+    # viewer.capture_screen_image(os.path.join(depthPath, "{:04d}-color.png".format(1)), do_render=True)
+    # viewer.destroy_window()
 
 def assign_point_cloud_information(source_cloud:o3d.geometry.PointCloud,ref_clouds:List[o3d.geometry.PointCloud],class_names:List[int]=None)->np.array:
     ref_cloud,ref_arr=gmu.create_identity_point_cloud(ref_clouds)
@@ -44,8 +165,114 @@ def filter_img_classifcation_by_neighbors (predictions:np.array,shape: Tuple[int
             arr=np.hstack((predictions[i-1:i+1,j-1:j+1].flatten(),np.full((weight-1),predictions[i,j])))         
             newPredictions[i,j]=np.argmax(np.bincount(arr)) 
     return np.reshape(newPredictions,(-1,1)).flatten()
+
+def remap_color_images_to_masks(images:List[np.array],colorList:np.array=None)->np.array:
+    """Remap the values of an image (RGB or grayscale) to indices given a colorList. 
+
+    **NOTE**: this is slow and error prone
     
-def project_pcd_to_rgbd_images (pointClouds:List[o3d.geometry.Geometry], imgNodes:List[ImageNode], depth_scale:float=1.0,depth_max:float=15)->Tuple[List[np.array],List[np.array],List[np.array]]:
+    Args:
+        1.images (List[np.array]): RGB or grayscale imagery.\n
+        2.colorList (np.array, optional): list with RGB or grayscale colors used for the remapping. If no colors are provided, the unique colors of the first image will be taken. Defaults to None.
+
+    Returns:
+        np.array: image [m,n,1] with indices as mask
+    """
+    #validate inputs
+    images=images if type(images)==list else [images]
+    # for img in images:
+    #     if img.shape[1]==1:
+    #         img=img
+    #     else:    
+    #         img=iu.rgb2gray(img)
+    images=[img if img.shape[2]==1 else iu.rgb2gray(img) for img in images]
+    colorList=colorList if colorList is not None else [ut.random_color() for u in range(np.unique(images[0]))]
+    colorList=colorList if colorList.shape[1]==1 else iu.rgb2gray(colorList)
+    newImages=[]
+    for img in images:
+        #remap values
+        for i,c in enumerate(colorList):
+            # test1=
+            # img=np.put(img,np.where(np.isclose(img,c,atol=0.01)),i)
+            img=np.where(np.isclose(img,c,atol=0.01),i+1,img)
+            
+        #replace other values by 0
+        img=np.where(img<1,0,img)
+        newImages.append(img)
+    return newImages
+    
+def project_meshes_to_rgbd_images (meshes:List[o3d.geometry.TriangleMesh], imgNodes:List[ImageNode], scale:float=1.0, fill_black:int=0)->Tuple[List[np.array],List[np.array]]:
+    """Project a set of meshes given camera parameters.
+
+    .. image:: ../../../docs/pics/colosseum/Raycasting_6.PNG
+
+    Args:
+        1.meshes (List[o3d.geometry.TriangleMesh]): set of TriangleMeshes.\n
+        2.imgNodes (List[ImageNode]): should contain imageWidth,imageHeight,cartesianTransform and focalLength35mm\n
+        3.scale (float, optional): scale to apply to imagery (typically for downscaling). Defaults to 1.\n
+        4.fill_black (int, optional): Region to fill in black pixels. 5 is a good value.\n
+        
+    Returns:
+        Tuple[List[np.array],List[np.array]]: colorImages,depthImages
+    """
+    #validate meshes
+    mesh=gmu.join_geometries(ut.item_to_list(meshes))
+    imgNodes=ut.item_to_list(imgNodes)
+    
+    #create lists
+    colorImages=[]
+    depthImages=[]    
+    
+    #create raytracing scene
+    scene = o3d.t.geometry.RaycastingScene()
+    reference=o3d.t.geometry.TriangleMesh.from_legacy(mesh)
+    scene.add_triangles(reference)
+    
+    #create a colorArray from the mesh triangles (color of first vertex is taken)
+    colors=np.asarray(mesh.vertex_colors)
+    indices=np.asarray(mesh.triangles)[:,0]
+    triangle_colors=colors[indices]
+    #append black color at the end of the array for the invalid hits
+    triangle_colors=np.vstack((triangle_colors,np.array([0,0,0])))
+    
+    #create rays  
+    for n in imgNodes:
+        rays = o3d.t.geometry.RaycastingScene.create_rays_pinhole(
+                                        intrinsic_matrix =n.get_intrinsic_camera_parameters().intrinsic_matrix,
+                                        extrinsic_matrix =np.linalg.inv(n.get_cartesian_transform()),
+                                        width_px=int(n.imageWidth),
+                                        height_px=int(n.imageHeight))
+        
+        #apply scale
+        rays=rays.numpy()
+        rays=o3d.core.Tensor(rays[::int(1/scale),::int(1/scale)])
+        #cast rays
+        ans = scene.cast_rays(rays) 
+        
+        #get triangle_ids that are hit per ray
+        triangle_ids=ans['primitive_ids'].numpy() # triangles
+        rows,columns=triangle_ids.shape        
+        triangle_ids=triangle_ids.flatten()
+        # replace invalid id's by last (which is the above added black color)
+        np.put(triangle_ids,np.where(triangle_ids==scene.INVALID_ID),triangle_colors.shape[0]-1) 
+        
+        #select colors 
+        colors=triangle_colors[triangle_ids]
+
+        #reshape array back to normal
+        colorImage=np.reshape(colors,(rows,columns,3))
+                
+        #fill black if necessary
+        colorImage=iu.fill_black_pixels(colorImage,fill_black)         if fill_black !=0       else colorImage
+        depthImage=iu.fill_black_pixels(ans['t_hit'].numpy(),fill_black)         if fill_black !=0       else ans['t_hit'].numpy()
+
+        #add to list
+        colorImages.append(colorImage)    
+        depthImages.append(depthImage)
+
+    return colorImages,depthImages
+
+def project_pcd_to_rgbd_images (pointClouds:List[o3d.geometry.Geometry], imgNodes:List[ImageNode], depth_max:float=15, fill_black:int=0)->Tuple[List[np.array],List[np.array]]:
     """Project a set of point cloud geometries given camera parameters. The given
 
     .. image:: ../../../docs/pics/ractracing1.PNG
@@ -53,32 +280,39 @@ def project_pcd_to_rgbd_images (pointClouds:List[o3d.geometry.Geometry], imgNode
     Args:
         1.pointClouds (List[o3d.geometry.PointCloud]): set of o3d point clouds.\n
         2.imgNodes (List[ImageNode]): should contain imageWidth,imageHeight,cartesianTransform and focalLength35mm\n
-        3.depth_scale (float, optional): Defaults to 1.0 (real distance).\n
-        4.depth_max (float, optional): cut off distance. Defaults to 15m.\n
+        3.depth_max (float, optional): cut off distance. Defaults to 15m.\n
+        4.fill_black (int, optional): Region to fill in black pixels. 5 is a good value.\n
+        
 
     Returns:
-        Tuple[List[np.array],List[np.array],List[np.array]]: colorImages,depthImages
+        Tuple[List[np.array],List[np.array]]: colorImages,depthImages
     """
     #validate point clouds
     pointClouds=ut.item_to_list(pointClouds)
     pointClouds=gmu.join_geometries(pointClouds)
+
+    #convert point cloud to tensor
     pcd = o3d.t.geometry.PointCloud.from_legacy(pointClouds)
+    
     colorImages=[]
     depthImages=[]
     #project color and depth from point cloud to images
     for n in ut.item_to_list(imgNodes):
-        intrinsic=n.get_intrinsic_camera_parameters().intrinsic_matrix
-        extrinsic= np.linalg.inv(n.get_cartesian_transform()) 
-        rgbd_reproj = pcd.project_to_rgbd_image(int(n.imageWidth),
-                                        int(n.imageHeight),
-                                        intrinsic,
-                                        extrinsic,
-                                        depth_scale=depth_scale,
+        # intrinsic=n.get_intrinsic_camera_parameters().intrinsic_matrix
+        # extrinsic= np.linalg.inv(n.get_cartesian_transform()) 
+        rgbd_reproj = pcd.project_to_rgbd_image(intrinsics =n.get_intrinsic_camera_parameters().intrinsic_matrix,
+                                        extrinsics =np.linalg.inv(n.get_cartesian_transform()),
+                                        width=int(n.imageWidth),
+                                        height=int(n.imageHeight),
+                                        depth_scale=1.0,
                                         depth_max=depth_max)
-        # reverse order so orientation matches image
         colorImage=np.asarray(rgbd_reproj.color.to_legacy())
-        # colorImage=colorImage[::-1,::-1]
+        colorImage=iu.fill_black_pixels(colorImage,fill_black)         if fill_black !=0       else colorImage
         depthImage=np.asarray(rgbd_reproj.depth.to_legacy())
+        depthImage=iu.fill_black_pixels(depthImage,fill_black)         if fill_black !=0       else depthImage
+                
+        # reverse order so orientation matches image
+        # colorImage=colorImage[::-1,::-1]
         # depthImage=depthImage[::-1,::-1]
     
         colorImages.append(colorImage)
