@@ -6,11 +6,11 @@ import os
 import os.path
 from typing import List
 
-from sklearn.neighbors import NearestNeighbors # to compute nearest neighbors
-import laspy # this is to process las point clouds
+from sklearn.neighbors import NearestNeighbors 
+import laspy 
 
 import geomapi.utils as ut
-import geomapi.utils.geometryutils as gt
+import geomapi.utils.geometryutils as gmu
 import matplotlib.pyplot as plt
 import numpy as np
 import open3d as o3d
@@ -18,9 +18,9 @@ import xlsxwriter
 from colour import Color
 from geomapi.nodes import *
 
-def compute_nearest_neighbor_in_bim(las:laspy.LasData,ref_clouds:List[] resolution:float = 0.1, )
+# def compute_nearest_neighbor_in_bim(las:laspy.LasData,ref_clouds:List[] resolution:float = 0.1, )
 
-    compute_nearest_neighbors(reference_points:np.array, query_points:np.array,n:int=1)
+#     compute_nearest_neighbors(reference_points:np.array, query_points:np.array,n:int=1)
 
 
 def get_boundingbox_of_list_of_geometries(geometries:List[o3d.geometry.PointCloud]) -> np.array:
@@ -36,11 +36,10 @@ def get_boundingbox_of_list_of_geometries(geometries:List[o3d.geometry.PointClou
     for n in geometries:
         n.get_resource()
         if n.resource is not None:
-            pcd.__iadd__(o3d.geometry.PointCloud(gt.get_oriented_bounds(gt.get_cartesian_bounds(n.resource))))
-    cartesianBounds = gt.get_cartesian_bounds(pcd.get_oriented_bounding_box())
+            pcd.__iadd__(o3d.geometry.PointCloud(gmu.get_oriented_bounds(gmu.get_cartesian_bounds(n.resource))))
+    cartesianBounds = gmu.get_cartesian_bounds(pcd.get_oriented_bounding_box())
     return cartesianBounds
 
-
 def match_BIM_points(sources: List[o3d.geometry.PointCloud], references: List[o3d.geometry.PointCloud], referenceIds = None, resolution : float = 0.02, t00: float=0.15, wd: float = 0.62, wn: float = 0.38, threshold: float = 0.7) -> np.array:
     """Determines the accuracy of a BIM model or object using a pointcloud\n
 
@@ -76,7 +75,7 @@ def match_BIM_points(sources: List[o3d.geometry.PointCloud], references: List[o3
                 referenceIdentityArray=np.vstack((referenceIdentityArray,np.full((len(referencePCD.points), 1), i+1)))
         referencePCDs.append(referencePCD)
     #Join the reference clouds together to one reference cloud
-    referencePCD=gt.join_geometries(referencePCDs)
+    referencePCD=gmu.join_geometries(referencePCDs)
     
     #check if the reference cloud has normals, if not compute them, this will be less accurate than when using the normals of the meshes
     if not referencePCD.has_normals():
@@ -89,9 +88,9 @@ def match_BIM_points(sources: List[o3d.geometry.PointCloud], references: List[o3
 
     #Check if the boundingboxes of the source clouds lie within the boundingbox of the reference
     #when the reference covers more then the captured data
-    inliers = gt.get_box_inliers(referencePCD.get_oriented_bounding_box(), [geometry.get_oriented_bounding_box() for geometry in sources], t_d = 500) 
+    inliers = gmu.get_box_inliers(referencePCD.get_oriented_bounding_box(), [geometry.get_oriented_bounding_box() for geometry in sources], t_d = 500) 
     #when the reference covers less than the captured data
-    inliers += gt.get_box_intersections(referencePCD.get_oriented_bounding_box(), [geometry.get_oriented_bounding_box() for geometry in sources])
+    inliers += gmu.get_box_intersections(referencePCD.get_oriented_bounding_box(), [geometry.get_oriented_bounding_box() for geometry in sources])
     
     if not inliers:
         #If reference and source share no overlap the sources containing no overlap will be ignored
@@ -105,7 +104,7 @@ def match_BIM_points(sources: List[o3d.geometry.PointCloud], references: List[o3
     
 
     #Join them in one source cloud for computations can be limiting for very large clouds
-    joinedPCD=gt.join_geometries(sourcePCDs)
+    joinedPCD=gmu.join_geometries(sourcePCDs)
     
     identityArray= [0] * len(joinedPCD.points)
     distances = [0.0] * len(joinedPCD.points)
