@@ -1,5 +1,5 @@
 """
-General Basic functions to support other modules
+General Basic functions to support other modules.
 """
 import datetime
 import ntpath
@@ -71,6 +71,34 @@ def get_extension(path:str) -> str:
     _,extension = os.path.splitext(path)
     return extension
 
+def get_min_average_and_max_value(arrays:List[np.array],ignoreZero:bool=True,threshold:float=0.0)->List[float]:
+    """Return an min,average and max values of a list of arrays. 
+
+    **NOTE** Nan is automatically ignored.\n
+    
+    Args:
+        1.arrays (List[np.array]): arrays are automatically flattened.\n
+        2.ignoreZero (bool, optional): Ignores 0.0 in the arrays array. Defaults to True.\n
+        3.Threshhold (float, optional): Return Nan if less than a threhold is not Nan. Defaults to 0.0.\n
+
+    Returns:
+        List[float]: average values
+    """
+    arrays=item_to_list(arrays)
+    minarr=np.full(len(arrays),np.nan)
+    meanarr=np.full(len(arrays),np.nan)
+    maxarr=np.full(len(arrays),np.nan)
+    
+    for i,a in enumerate(arrays):
+        a=a.flatten()
+        if ignoreZero:
+            a=a[np.nonzero(a)]
+            if any(a) and a.size > threshold*minarr.size:                
+                minarr[i]=np.nanmin(a)        
+                meanarr[i]=np.nanmean(a)
+                maxarr[i]=np.nanmax(a) 
+    return minarr  ,meanarr  ,maxarr
+
 def replace_str_index(text:str,index:int,replacement:str='_'):
     """Replace a string character at the location of the index with the replacement.\n
 
