@@ -44,9 +44,32 @@ def image_resize(img:np.array,width:int=None,height:int=None,scale:float=0.5)->n
     
     return cv2.resize(img, dim, interpolation = cv2.INTER_AREA)
 
+def grb01_to_rgb255(image:np.array)->np.array:
+    """Return image RGB [0-1] interval as RGB image [0-255] interval.\n
+    """
+    norm_image = cv2.normalize(image, None, alpha = 0, beta = 255, norm_type = cv2.NORM_MINMAX, dtype = cv2.CV_32F)
+    return norm_image.astype(np.uint8)
+
 def rgb2gray(rgb:np.array)->np.array:
     return np.dot(rgb[...,:3], [0.2989, 0.5870, 0.1140])
+
+def gray2rgb(gray:np.array)->np.array:
+    rgb = np.zeros((*gray.shape, 3))
+    rgb[..., :] = gray[..., np.newaxis]
+    return rgb
  
+def fill_black_pixels(image:np.array,region:int=5)->np.array:
+    """Fill in the black pixels in an RGB image given a search distance.\n
+
+    Args:
+        image (np.array)\n
+        region (int, optional): search distance. Defaults to 5.\n
+
+    Returns:
+        np.array: image
+    """
+    kernel = np.ones((region,region),np.uint8)
+    return cv2.morphologyEx(image, cv2.MORPH_CLOSE, kernel)
 
 def subdivide_image(image:np.array,m:int=None,n:int=None,width:int=None,height:int=None,includeLast:bool=True)->Tuple[List[np.array],List[Tuple[int,int,int,int]]]:
     """Subdivide image into [mxn] parts.\n
@@ -279,6 +302,8 @@ def match_images(img1: np.array, img2: np.array, featureType: str = "orb", match
 
 def create_transformation_matrix(R: np.array, t: np.array) -> np.array:
     """Combines a rotation matrix and translation vector into a 4x4 transformation matrix
+    
+    **NOTE**: this function should be in utils and is already present
 
     Args:
         R (np.array): 3x3 rotation matrix
@@ -293,6 +318,8 @@ def create_transformation_matrix(R: np.array, t: np.array) -> np.array:
 def split_transformation_matrix(T:np.array):
     """Splits a transformation matrix into a rotation and translationmatrix
 
+    **NOTE**: this function should be in utils and is already present in get_translation
+    
     Args:
         T (np.array): The 4x4 transormationmatrix
 
