@@ -1,5 +1,3 @@
-import copy
-import math
 import os
 from pathlib import Path
 import shutil
@@ -9,17 +7,12 @@ from multiprocessing.sharedctypes import Value
 
 import cv2
 import geomapi.utils as ut
-import ifcopenshell
 import numpy as np
 import open3d as o3d
-import PIL
-import pye57
 import rdflib
 from geomapi.nodes import *
-from ifcopenshell.util.selector import Selector
 from rdflib import RDF, RDFS, Graph, Literal, URIRef
 
-
 class TestNode(unittest.TestCase):
 
 ################################## SETUP/TEARDOWN CLASS ######################
