@@ -1,24 +1,17 @@
-import copy
 import datetime
-import math
 import os
 from pathlib import Path
 import shutil
 import time
 import unittest
 from multiprocessing.sharedctypes import Value
-from re import S
 
 import cv2
 import geomapi.utils as ut
-import ifcopenshell
 import numpy as np
 import open3d as o3d
-import PIL
-import pye57
 import rdflib
 from geomapi.nodes import *
-from ifcopenshell.util.selector import Selector
 from rdflib import RDF, RDFS, Graph, Literal, URIRef
 
 
