@@ -1,26 +1,13 @@
-import copy
-import math
 import os
 import shutil
 import time
 import unittest
 from multiprocessing.sharedctypes import Value
-
-import cv2
-import geomapi.utils as ut
-import geomapi.utils.geometryutils as gt
-import ifcopenshell
-import numpy as np
 import open3d as o3d
-import PIL
-import pye57
 import rdflib
 from geomapi.nodes import *
-from ifcopenshell.util.selector import Selector
-from PIL import Image
 from rdflib import RDF, RDFS, Graph, Literal, URIRef
 
-
 class TestNode(unittest.TestCase):
 
 ################################## SETUP/TEARDOWN CLASS ######################
@@ -212,6 +199,5 @@ class TestNode(unittest.TestCase):
         node= SessionNode(graph=self.combinedGraph)
         node.session_to_graph(os.path.join(self.resourcePath,'combinedGraph.ttl'))
 
-
 if __name__ == '__main__':
     unittest.main()
