@@ -1,5 +1,3 @@
-import copy
-import math
 import os
 import shutil
 import time
@@ -9,20 +7,10 @@ from multiprocessing.sharedctypes import Value
 
 import cv2
 import geomapi.utils as ut
-import ifcopenshell
 import numpy as np
-import open3d as o3d
 import PIL
-import pye57
-from geomapi.nodes.bimnode import BIMNode
-from geomapi.nodes.imagenode import ImageNode
-from geomapi.nodes.meshnode import MeshNode
-from geomapi.nodes.orthonode import OrthoNode
-from geomapi.nodes.pointcloudnode import PointCloudNode
-from ifcopenshell.util.selector import Selector
 from rdflib import RDF, RDFS, XSD, Graph, Literal, URIRef
 
-
 class TestUtils(unittest.TestCase):
  ################################## SETUP/TEARDOWN CLASS ######################
     @classmethod
@@ -154,14 +142,6 @@ class TestUtils(unittest.TestCase):
         test=ut.validate_string('[this<has$to^change]')
         self.assertEqual(test,'_this_has_to_change_')
 
-    def test_get_node_resource_extensions(self):
-        self.assertEqual(len(ut.MESH_EXTENSION),len(ut.get_node_resource_extensions(str(type(MeshNode())))))
-        self.assertEqual(len(ut.MESH_EXTENSION),len(ut.get_node_resource_extensions(str(type(BIMNode())))))
-        self.assertEqual(len(ut.PCD_EXTENSION),len(ut.get_node_resource_extensions(str(type(PointCloudNode())))))
-        self.assertEqual(len(ut.IMG_EXTENSION),len(ut.get_node_resource_extensions(str(type(ImageNode())))))
-        self.assertEqual(len(ut.IMG_EXTENSION),len(ut.get_node_resource_extensions(str(type(OrthoNode())))))
-        self.assertEqual(len(ut.MESH_EXTENSION),len(ut.get_node_resource_extensions(str(type(MeshNode())))))
-
     def test_clean_attributes_list(self):
         list=['blablabla',
             'graph','graphPath','subject','fullResourcePath','kwargs', 'orientedBoundingBox',
